==> sisu_3.1.11.orig.tar.xz: sisu-3.1.11/lib/sisu/v3dv/html_minitoc.rb <==
# encoding: utf-8
=begin

 * Name: SiSU

 * Description: a framework for document structuring, publishing and search
   minitoc

 * Author: Ralph Amissah

 * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.

 * License: GPL 3 or later:

   SiSU, a framework for document structuring, publishing and search

   Copyright (C) Ralph Amissah

   This program is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the Free
   Software Foundation, either version 3 of the License, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
   more details.

   You should have received a copy of the GNU General Public License along with
   this program. If not, see <http://www.gnu.org/licenses/>.

   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
   <http://www.fsf.org/licensing/licenses/gpl.html>
   <http://www.gnu.org/copyleft/gpl.html>

   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>

 * SiSU uses:
   * Standard SiSU markup syntax,
   * Standard SiSU meta-markup syntax, and the
   * Standard SiSU object citation numbering and system

 * Hompages:
   <http://www.jus.uio.no/sisu>
   <http://www.sisudoc.org>

 * Download:
   <http://www.jus.uio.no/sisu/SiSU/download.html>

 * Ralph Amissah
   <ralph@amissah.com>
   <ralph.amissah@gmail.com>

 ** Description: system environment, resource control and configuration details

=end
  module SiSU_HTML_MiniToc
    require_relative 'html_tune'                        # html_tune.rb
      include SiSU_HTML_Tune
    class TocMini
      @@seg_mini=nil
      @@seg_url=''
      @@firstseg=nil
      def initialize(md,data)
        @md,@data=md,data
        @pat_strip_heading_name=/<a name="h?\d.*?">(.+?)<\/a>/
        @tell=SiSU_Screen::Ansi.new(@md.opt.cmd) if @md
      end
      def songsheet
        SiSU_Screen::Ansi.new(@md.opt.cmd,'Toc').txt_grey if @md.opt.cmd =~/[MVv]/
        toc=nil
        @toc=[]
        @data.each do |txt|
          if (txt.is =='heading' or txt.is =='heading_insert')
            txt.obj.gsub!(/(?:#{Mx[:en_a_o]}|#{Mx[:en_b_o]}).+?(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/m,'') #remove endnotes from toc
            txt.obj.gsub!(/<a name="-\d+" href="#_\d+">&nbsp;<sup>\d+<\/sup>&nbsp;<\/a>/,'')
            txt.obj.gsub!(@pat_strip_heading_name,'\1')
            txt.obj.gsub(/(.*?)<a name="(\d+)"><\/a>(.*)/,'\1') #2002w42 altered gsub! - problematic? - suspect
            toc=case txt.ln
            when 1; TocMini.new(@md,txt).level_1
            when 2; TocMini.new(@md,txt).level_2
            when 3; TocMini.new(@md,txt).level_3
            when 4; TocMini.new(@md,txt).level_4
            when 5; TocMini.new(@md,txt).level_5
            when 6; TocMini.new(@md,txt).level_6
            else
            end
            @toc << toc
          end
        end
        @toc
      end
    protected
      def level_concordance
        format_head_toc=SiSU_HTML_Format::HeadToc.new(@md)
        @@seg_mini << format_head_toc.mini_seg_concordance
      end
      def level_metadata
        format_head_toc=SiSU_HTML_Format::HeadToc.new(@md)
        @@seg_mini << format_head_toc.mini_seg_metadata
      end
      def level_word_index
        format_head_toc=SiSU_HTML_Format::HeadToc.new(@d0c)
        @@seg_mini << format_head_toc.mini_concordance
      end
      def level_1
        txt=@data
        if (txt.is =='heading' or txt.is =='heading_insert') \
        and txt.ocn !=0
          txt.obj.gsub!(@pat_strip_heading_name,'\1')
        end
        title=unless txt.obj =~/Document Information/; txt.obj
        else
          link='metadata'
          %{<b><a href="#{link}#{@md.lang_code_insert}#{Sfx[:html]}">#{txt.obj}</a></b>}
        end
        toc={}
        txt_obj={ txt: title }
        format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
        toc_mini=if txt.name =~/^meta/ and txt.obj=~/Document Information/
          format_toc.mini_tail
        else format_toc.mini_lev1
        end
        toc_mini
      end
      def level_2
        txt=@data
        if (txt.is =='heading' or txt.is =='heading_insert') \
        and txt.ocn !=0
          txt.obj.gsub!(@pat_strip_heading_name,'\1')
        end
        txt_obj={ txt: txt.obj }
        format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
        toc_mini=format_toc.mini_lev2
        toc_mini
      end
      def level_3
        txt=@data
        txt_obj={ txt: txt.obj }
        format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
        toc_mini=format_toc.mini_lev3
        toc_mini
      end
      def level_4
        txt=@data
        unless txt =~/~metadata/
          if txt.ln ==4
            seg_link=%{  <a href="#{txt.name}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top">
    #{txt.obj}
  </a> }
            @@seg_url=txt.name
          elsif txt.obj =~/\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+/
            seg_link=txt.obj.gsub(/^(\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+)(.*)/,
              %{<a href="\\2#{@md.lang_code_insert}#{Sfx[:html]}" } +
              %{target="_top">\\1 \\2</a> })
          end
          txt_obj={ txt: seg_link }
          format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
          toc_mini=format_toc.mini_lev4
          toc_mini
        end
      end
      def level_5
        txt=@data
        if (txt.is =='heading' or txt.is =='heading_insert') \
        and txt.ocn !=0
          txt.obj.gsub!(@pat_strip_heading_name,'\1')
        end
        toc={}
          lnk_n_txt=%{  <a href="#{@@seg_url}#{@md.lang_code_insert}#{Sfx[:html]}##{txt.ocn}">
    #{txt.obj}
  </a>}
          txt_obj={ txt: lnk_n_txt }
          format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
          toc_mini=format_toc.mini_lev5
        toc_mini
      end
      def level_6
        txt=@data
        if (txt.is =='heading' or txt.is =='heading_insert') \
        and txt.ocn !=0
          txt.obj.gsub!(@pat_strip_heading_name,'\1')
        end
        toc={}
          lnk_n_txt=%{  <a href="#{@@seg_url}#{@md.lang_code_insert}#{Sfx[:html]}##{txt.ocn}">
    #{txt.obj}
  </a>}
          txt_obj={ txt: lnk_n_txt }
          format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
          toc_mini=format_toc.mini_lev6
        toc_mini
      end
    end
  end
__END__

==> sisu_3.1.12.orig.tar.xz: sisu-3.1.12/lib/sisu/v3dv/html_minitoc.rb <==
# encoding: utf-8
=begin

 * Name: SiSU

 * Description: a framework for document structuring, publishing and search
   minitoc

 * Author: Ralph Amissah

 * Copyright: (C) 1997 - 2012, Ralph Amissah, All Rights Reserved.

 * License: GPL 3 or later:

   SiSU, a framework for document structuring, publishing and search

   Copyright (C) Ralph Amissah

   This program is free software: you can redistribute it and/or modify it
   under the terms of the GNU General Public License as published by the Free
   Software Foundation, either version 3 of the License, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful, but WITHOUT
   ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
   FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License for
   more details.

   You should have received a copy of the GNU General Public License along with
   this program. If not, see <http://www.gnu.org/licenses/>.

   If you have Internet connection, the latest version of the GPL should be
   available at these locations:
   <http://www.fsf.org/licensing/licenses/gpl.html>
   <http://www.gnu.org/copyleft/gpl.html>

   <http://www.jus.uio.no/sisu/gpl.fsf/toc.html>
   <http://www.jus.uio.no/sisu/gpl.fsf/doc.html>
   <http://www.jus.uio.no/sisu/gpl.fsf/plain.txt>

 * SiSU uses:
   * Standard SiSU markup syntax,
   * Standard SiSU meta-markup syntax, and the
   * Standard SiSU object citation numbering and system

 * Hompages:
   <http://www.jus.uio.no/sisu>
   <http://www.sisudoc.org>

 * Download:
   <http://www.jus.uio.no/sisu/SiSU/download.html>

 * Ralph Amissah
   <ralph@amissah.com>
   <ralph.amissah@gmail.com>

 ** Description: system environment, resource control and configuration details

=end
  module SiSU_HTML_MiniToc
    require_relative 'html_tune'                        # html_tune.rb
      include SiSU_HTML_Tune
    class TocMini
      @@seg_mini=nil
      @@seg_url=''
      @@firstseg=nil
      def initialize(md,data)
        @md,@data=md,data
        @pat_strip_heading_name=/<a name="h?\d.*?">(.+?)<\/a>/
        @tell=SiSU_Screen::Ansi.new(@md.opt.cmd) if @md
      end
      def songsheet
        SiSU_Screen::Ansi.new(@md.opt.cmd,'Toc').txt_grey if @md.opt.cmd =~/[MVv]/
        toc=nil
        @toc=[]
        @data.each do |txt|
          if (txt.is =='heading' or txt.is =='heading_insert')
            txt.obj=txt.obj.gsub(/(?:#{Mx[:en_a_o]}|#{Mx[:en_b_o]}).+?(?:#{Mx[:en_a_c]}|#{Mx[:en_b_c]})/m,''). #remove endnotes from toc
              gsub(/<a name="-\d+" href="#_\d+">&nbsp;<sup>\d+<\/sup>&nbsp;<\/a>/,'').
              gsub(@pat_strip_heading_name,'\1')
              #gsub(/(.*?)<a name="(\d+)"><\/a>(.*)/,'\1') #2002w42 altered gsub - problematic? - suspect
            toc=case txt.ln
            when 1; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_1
            when 2; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_2
            when 3; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_3
            when 4; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_4
            when 5; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_5
            when 6; SiSU_HTML_MiniToc::TocMini.new(@md,txt).level_6
            else
            end
            @toc << toc
          end
        end
        @toc
      end
    protected
      def level_concordance
        format_head_toc=SiSU_HTML_Format::HeadToc.new(@md)
        @@seg_mini << format_head_toc.mini_seg_concordance
      end
      def level_metadata
        format_head_toc=SiSU_HTML_Format::HeadToc.new(@md)
        @@seg_mini << format_head_toc.mini_seg_metadata
      end
      def level_word_index
        format_head_toc=SiSU_HTML_Format::HeadToc.new(@d0c)
        @@seg_mini << format_head_toc.mini_concordance
      end
      def level_1
        txt=@data
        if (txt.is =='heading' or txt.is =='heading_insert') \
        and txt.ocn !=0
          txt.obj=txt.obj.gsub(@pat_strip_heading_name,'\1')
        end
        title=unless txt.obj =~/Document Information/; txt.obj
        else
          link='metadata'
          %{<b><a href="#{link}#{@md.lang_code_insert}#{Sfx[:html]}">#{txt.obj}</a></b>}
        end
        toc={}
        txt_obj={ txt: title }
        format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
        toc_mini=if txt.name =~/^meta/ and txt.obj=~/Document Information/
          format_toc.mini_tail
        else format_toc.mini_lev1
        end
        toc_mini
      end
      def level_2
        txt=@data
        if (txt.is =='heading' or txt.is =='heading_insert') \
        and txt.ocn !=0
          txt.obj=txt.obj.gsub(@pat_strip_heading_name,'\1')
        end
        txt_obj={ txt: txt.obj }
        format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
        toc_mini=format_toc.mini_lev2
        toc_mini
      end
      def level_3
        txt=@data
        txt_obj={ txt: txt.obj }
        format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
        toc_mini=format_toc.mini_lev3
        toc_mini
      end
      def level_4
        txt=@data
        unless txt =~/~metadata/
          if txt.ln ==4
            seg_link=%{  <a href="#{txt.name}#{@md.lang_code_insert}#{Sfx[:html]}" target="_top">
    #{txt.obj}
  </a> }
            @@seg_url=txt.name
          elsif txt.obj =~/\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+/
            seg_link=txt.obj.gsub(/^(\d+.\d+.\d+.\d+|\d+.\d+.\d+|\d+.\d+|\d+)(.*)/,
              %{<a href="\\2#{@md.lang_code_insert}#{Sfx[:html]}" } +
              %{target="_top">\\1 \\2</a> })
          end
          txt_obj={ txt: seg_link }
          format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
          toc_mini=format_toc.mini_lev4
          toc_mini
        end
      end
      def level_5
        txt=@data
        if (txt.is =='heading' or txt.is =='heading_insert') \
        and txt.ocn !=0
          txt.obj=txt.obj.gsub(@pat_strip_heading_name,'\1')
        end
        toc={}
          lnk_n_txt=%{  <a href="#{@@seg_url}#{@md.lang_code_insert}#{Sfx[:html]}##{txt.ocn}">
    #{txt.obj}
  </a>}
          txt_obj={ txt: lnk_n_txt }
          format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
          toc_mini=format_toc.mini_lev5
        toc_mini
      end
      def level_6
        txt=@data
        if (txt.is =='heading' or txt.is =='heading_insert') \
        and txt.ocn !=0
          txt.obj=txt.obj.gsub(@pat_strip_heading_name,'\1')
        end
        toc={}
          lnk_n_txt=%{  <a href="#{@@seg_url}#{@md.lang_code_insert}#{Sfx[:html]}##{txt.ocn}">
    #{txt.obj}
  </a>}
          txt_obj={ txt: lnk_n_txt }
          format_toc=SiSU_HTML_Format::FormatToc.new(@md,txt_obj)
          toc_mini=format_toc.mini_lev6
        toc_mini
      end
    end
  end
__END__
